Status bar appearance. has no effect unless
standalone more is enabled (see capable).
"If content is set to default, the status bar appears normal. If set to
black, the status bar has a black background. If set to black-translucent,
the status bar is black and translucent. If set to default or black, the
web content is displayed below the status bar. If set to black-translucent,
the web content is displayed on the entire screen, partially obscured by
the status bar. The default value is default."