- .meta
A meta object created by meta() or as_meta(), or returned
by a meta_*() object.
- application_name
Name of web application (only should be used if the
website is used as an app).
- theme_color
Theme Color for Chrome, Firefox OS and Opera, e.g.
"#00589a".
- description
Short description of the document (limit to 150
characters), This content may be used as a part of search engine results.
- robots
Control the behavior of search engine crawling and indexing,
e.g. "index,follow". Valid names are "index", "noindex", "follow",
"nofollow". May be a vector or a single string with comma-separated
values.
See https://www.robotstxt.org/meta.html for more information.
- generator
Identify the software used to build the document (i.e. -
WordPress, Dreamweaver).
- subject
Short description of your document's subject.
- rating
Gives a general age rating based on the document's content,
e.g. "General".
- referrer
Allows control over how referrer information is passed, .e.g.
"no-referrer". Valid values include "no-referrer",
"no-referrer-when-downgrade", "same-origin", "origin",
"strict-origin", "origin-when-cross-origin",
"strict-origin-when-cross-origin", or "unsafe-url".